import * as tslib_1 from "tslib";
import { Bind, Logger, LogLevel } from '@samwise-tech/core';
import { Inject, Injectable } from '@samwise-tech/di';
import { Observable, Subject } from 'rxjs';
import { filter } from 'rxjs/operators';
import { JsConsole } from './js-console';
let BrowserLogger = class BrowserLogger extends Logger {
    constructor(nativeConsole) {
        super();
        this.nativeConsole = nativeConsole;
        this.events$ = new Subject();
        Bind.to(this);
    }
    getConsoleEvents(allowedLogLevels) {
        return this.events$.pipe(filter(({ level }) => allowedLogLevels.includes(level)));
    }
    log(...args) {
        this.callMethod(LogLevel.Log, ...args);
    }
    warn(warnMsg, ...args) {
        this.callMethod(LogLevel.Warn, ...[warnMsg, ...args]);
    }
    error(errMsg) {
        const error = errMsg instanceof Error ? errMsg : new Error(errMsg);
        this.callMethod(LogLevel.Error, error);
    }
    debug(...args) {
        this.callMethod(LogLevel.Debug, ...args);
    }
    info(infoMsg, ...args) {
        this.callMethod(LogLevel.Info, ...[infoMsg, ...args]);
    }
    onCatch(label) {
        return (err) => {
            if (err instanceof Error) {
                this.error(err);
            }
            else {
                this.error(label);
                this.debug(`${label} Due:`, err);
            }
            return Promise.reject(err);
        };
    }
    callMethod(level, ...args) {
        if (process.env.NODE_ENV !== 'production') {
            this.events$.next({ level, data: args });
            this.nativeConsole[level](...args); // ( as (...args: any[]) => void)
        }
    }
};
tslib_1.__decorate([
    Bind,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Array]),
    tslib_1.__metadata("design:returntype", Observable)
], BrowserLogger.prototype, "getConsoleEvents", null);
tslib_1.__decorate([
    Bind,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", void 0)
], BrowserLogger.prototype, "log", null);
tslib_1.__decorate([
    Bind,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], BrowserLogger.prototype, "warn", null);
tslib_1.__decorate([
    Bind,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", void 0)
], BrowserLogger.prototype, "error", null);
tslib_1.__decorate([
    Bind,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", void 0)
], BrowserLogger.prototype, "debug", null);
tslib_1.__decorate([
    Bind,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], BrowserLogger.prototype, "info", null);
BrowserLogger = tslib_1.__decorate([
    Injectable(),
    tslib_1.__param(0, Inject(JsConsole)),
    tslib_1.__metadata("design:paramtypes", [Object])
], BrowserLogger);
export { BrowserLogger };
//# sourceMappingURL=logger.js.map